[Mulgara-svn] r1815 - trunk/src/jar/query/java/org/mulgara/query

pag at mulgara.org pag at mulgara.org
Wed Oct 7 02:57:05 UTC 2009


Author: pag
Date: 2009-10-06 19:57:04 -0700 (Tue, 06 Oct 2009)
New Revision: 1815

Modified:
   trunk/src/jar/query/java/org/mulgara/query/FunctionResolverRegistry.java
Log:
Changed the registry to use a list instead of a set, so that preference can be provided to the functions that are loaded first

Modified: trunk/src/jar/query/java/org/mulgara/query/FunctionResolverRegistry.java
===================================================================
--- trunk/src/jar/query/java/org/mulgara/query/FunctionResolverRegistry.java	2009-10-06 06:45:58 UTC (rev 1814)
+++ trunk/src/jar/query/java/org/mulgara/query/FunctionResolverRegistry.java	2009-10-07 02:57:04 UTC (rev 1815)
@@ -18,10 +18,10 @@
 
 import org.mulgara.util.Reflect;
 
+import java.util.ArrayList;
 import java.util.Collections;
-import java.util.HashSet;
 import java.util.Iterator;
-import java.util.Set;
+import java.util.List;
 
 import javax.xml.xpath.XPathFunctionResolver;
 
@@ -37,14 +37,14 @@
   /** The singleton of this object */
   static private FunctionResolverRegistry registry = new FunctionResolverRegistry();
 
-  /** The set of registered resolvers */
-  private Set<XPathFunctionResolver> registered;
+  /** The list of registered resolvers */
+  private List<XPathFunctionResolver> registered;
 
   /**
    * Constructs the singleton resolver.
    */
   private FunctionResolverRegistry() {
-    registered = new HashSet<XPathFunctionResolver>();
+    registered = new ArrayList<XPathFunctionResolver>();
   }
 
   /**
@@ -81,6 +81,6 @@
    * @return an Iterator for the registry.
    */
   public Iterator<XPathFunctionResolver> iterator() {
-    return Collections.unmodifiableSet(registered).iterator();
+    return Collections.unmodifiableList(registered).iterator();
   }
 }




More information about the Mulgara-svn mailing list